@@ -1,3 +1,3 @@
-from .cli import cli
+from acdc_nn.cli import cli
 if __name__ == '__main__':
 	cli()
