@@ -1,5 +1,5 @@
-from . import acdc_nn
-from . import util
+from acdc_nn import acdc_nn
+from acdc_nn import util
 import ddgun
 
 import click
@@ -98,11 +98,11 @@ Uses a trained ACDC-NN that requires protein structural information.'''
 def load_nn(seq):
 	return acdc_nn.ACDCSeq() if seq else acdc_nn.ACDC3D()
 
-@functools.lru_cache()
+@functools.lru_cache
 def load_prot_seq(profile):
 	return ddgun.Profile(profile)
 
-@functools.lru_cache()
+@functools.lru_cache
 def load_prot_3d(profile, pdb, chain):
 	return util.getProfile(profile), acdc_nn.Structure(pdb, chain) #FIXME use Profile
 
